# Title Slide

---

# Paragraphs

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris ultricies
tempus ultricies. Ut porta scelerisque viverra. Pellentesque aliquam metus
scelerisque dui ultricies, auctor dictum erat aliquet. Integer vehicula nunc
elit, vel iaculis lorem facilisis non.

Vivamus ante mauris, pellentesque et rhoncus ut, condimentum sed ipsum.
Nullam eu molestie sapien. Curabitur imperdiet, ligula id blandit sagittis,
libero quam consectetur felis, ac pharetra metus lectus vitae leo. Mauris
lacinia fermentum augue.

---

# Blockquotes

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris ultricies
> tempus ultricies. Ut porta scelerisque viverra. Pellentesque aliquam metus
> scelerisque dui ultricies, auctor dictum erat aliquet. Integer vehicula nunc
> elit, vel iaculis lorem facilisis non.

---

# Subheadings and Emphasis

## Italic

*Lorem ipsum dolor sit amet*

## Bold

**Lorem ipsum dolor sit amet**

---

# Lists

## Unordered List

- Markdown
- ReStructured Text
- Textile

## Ordered List

1. Python
2. JavaScript
3. HTML5

---

# Second Title Slide

---

# Code

## Single Word

Hello `World`

## Python

    !python
    def multiply (x, y):
        return x * y

## JavaScript

    !javascript
    multiply: function (x, y) {
      return x * y;
    }

## HTML

    !html
    <!doctype html>
    <html>
      <head></head>
      <body></body>
    </html>

---

# Images

![img](img.png)

---

# View Presenter Notes

This slide has presenter notes. Press `p` to view them.

# Presenter Notes

Hello from presenter notes

---

# Other features

View other features in the help sidebar by pressing `h`

---

# Unicode

This is ünicô∂e
